@@ -33,6 +33,10 @@ Start::Start(QWidget *parent) :
 
     m_ui->startTimeEdit->setDateTime(QDateTime::currentDateTime());
     m_ui->endTimeEdit->setDateTime(QDateTime::currentDateTime());
+    m_ui->weightBeforeEdit->setInputMethodHints(Qt::ImhDigitsOnly);
+    m_ui->weightAfterEdit->setInputMethodHints(Qt::ImhDigitsOnly);
+    m_ui->mlBeforeEdit->setInputMethodHints(Qt::ImhDigitsOnly);
+    m_ui->mlAfterEdit->setInputMethodHints(Qt::ImhDigitsOnly);
     m_ui->weightBeforeEdit->setInputMask("009.000");
     m_ui->weightAfterEdit->setInputMask("009.000");
     m_ui->mlBeforeEdit->setInputMask("009.000");
